#
# spec file for package libopenshot
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 19

Name:           libopenshot
Version:        0.2.5+11
Release:        lp152.1.3
Summary:        The core library for the OpenShot video editor
License:        LGPL-3.0-or-later
Group:          Productivity/Multimedia/Other
URL:            https://openshot.org/
Source0:        libopenshot-%{version}.tar.xz

BuildRequires:  cmake
BuildRequires:  cppzmq-devel
BuildRequires:  gcc-c++
BuildRequires:  libopenshot-audio-devel >= 0.1.8
BuildRequires:  pkgconfig
BuildRequires:  ruby-devel
BuildRequires:  swig
# Disabled as cmake does not detect it
BuildRequires:  pkgconfig(Magick++)
BuildRequires:  pkgconfig(Qt5Core) >= 5.2.0
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Multimedia)
BuildRequires:  pkgconfig(Qt5MultimediaWidgets)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(UnitTest++)
BuildRequires:  pkgconfig(jsoncpp)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavdevice)
BuildRequires:  pkgconfig(libavfilter)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavresample)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(python3)

%description
A library for video editing, composition, animation, and playback,
which focuses on The library is written in C++ and includes full
bindings for Python and Ruby.

%package -n     %{name}%{sover}
Summary:        The core library for the OpenShot video editor
Group:          System/Libraries

%description -n %{name}%{sover}
A library for video editing, composition, animation, and playback,
which focuses on The library is written in C++ and includes full
bindings for Python and Ruby. It features:

* Multi-layer compositing
* Video and audio effects (chroma key, color adjustment,
  grayscale, etc.)
* Animation curves (Bézier, linear, constant)
* Time mapping (curve-based slow-down, speed-up, reverse)
* Audio mixing & resampling (curve-based)
* Audio plug-ins (VST & AU)
* Telecine and Inverse Telecine (film to TV, TV to film)
* Frame rate conversions
* Multi-processor support
* Uses ffmpeg for format and codec support

This package contains the shared library.

%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{name}%{sover} = %{version}

%description    devel
A library for video editing, composition, animation, and playback,
which focuses on The library is written in C++.

This package contains header files and libraries needed to develop
application that use %{name}.

%package -n     python3-openshot
Summary:        Python bindings for the OpenShot library
Group:          Development/Languages/Python

%description -n python3-openshot
This package provides the Python bindings for the OpenShot library.

%prep
%autosetup -p1

%build
# operators of base classes are not supposed to be used here, we can ignore it therefore.
sed -i '/^set(CMAKE_CXX_FLAGS/d' CMakeLists.txt
export CXXFLAGS="%{optflags} -Wno-return-type"

%cmake \
	-DCMAKE_SHARED_LINKER_FLAGS="-Wl,--as-needed" \
	-DCMAKE_CXX_FLAGS="$CXXFLAGS" \
	-DFFMPEG_INCLUDE_DIR=%{_includedir}/ffmpeg \
	-DUSE_SYSTEM_JSONCPP=ON \
	%{nil}
%cmake_build

%install
%cmake_install

%post   -n %{name}%{sover} -p /sbin/ldconfig
%postun -n %{name}%{sover} -p /sbin/ldconfig

%files -n %{name}%{sover}
%license COPYING
%doc AUTHORS
%{_libdir}/%{name}.so.*

%files devel
%{_includedir}/%{name}/
%{_libdir}/%{name}.so
%{_libdir}/ruby/vendor_ruby/*/*-linux-gnu/openshot.so

%files -n python3-openshot
%{python3_sitearch}/*openshot*

%changelog
* Thu Mar 12 2020 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 0.2.5+11:
  * ReaderBase_Tests: 100%% internal coverage (#462)
  * Updating auto-stale conditions (90 days warning, 10 days to respond, only issues, ignore assigned issues)
  * Adding support for proper absolute/canonical path detection and replacement
  * Adding stale bot for github issue management
  * Adding ability for a Clip to auto-detect and instantiate a Timeline Reader from the *.osp file type. Added new Timeline constructor, to auto load UTF-8 JSON file, and regex convert all paths to absolute. Fixed a dead lock issue when a Timeline loads another Timeline.
  * Bump version to -dev2 (merge master back to develop)
  * Fixing abs -> fabs regression. Not sure how this worked before.
  * Fix ColorShift classname in EffectInfo::CreateEffect
  * Release branch for 0.2.5 (SO 19)
- enable Magick++ again
* Sun Aug 18 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to current master (devel) branch, fixes build for Factory.
- Run spec-cleaner, use modern macros.
- Enable ruby-devel BuildRequires, fixed upstream.
- Replace ImageMagick-devel with disabled pkgconfig(Magick++)
  BuildRequires, it's not detected either way.
* Fri May  3 2019 Adrian Schröter <adrian@suse.de>
- update to version 0.2.3
  * Bumping version to 0.2.3 (SO 17)
  * Integration of resvg SVG library (optional during build) (#185)
  * Improved Keyframe Performance (#197)
  * MP3 Special Handling & Missing Frame Refactor (#196)
  * Fix default sizes on readers without MAX_WIDTH and MAX_HEIGHT settings (#188)
  * Adding new settings class to be used for changing realtime settings used by libopenshot, such as scaling mode for preview vs final render, or hardware decode, etc... (#183)
  * Integrate Constant Rate Factor (CRF) for FFmpegWriter (#186)
  * Improving cache performance by preventing the cache from getting behind the currently displaying frame # (#179)
  * Set video bit rate to 0 if an invalid bit rate detected (which happens when using crf) (#191)
  * Invalid SetMaxSize Logic and Invalid CRF q settings in FFmpegWriter (#198)
  * Refactor FFmpegWriter Open() and PrepareStreams() methods, so that SetOption() can be called between them. (#193)
  * Some polishing for the cmake ReSVG discovery (#187)
  * Adding condition before calling av_frame_free (in AV_FREE_FRAME macro) (#184)
  * tests/CMakeLists: Use same dependencies as src/ (#163)
  * Remove Eclipse files and add to gitignore (#178)
  * Fixing Scale Mode (None) in previews (#182)
  * Exclude git tags from kicking off GitLab builds (for libopenshot)
  * Update readme to use markdown and update copyright to 2019 (#94)
  * Update README and INSTALL files (including build instructions) (#194)
  * Add git log file with commits up to the previous release (#192)
* Mon Sep 24 2018 Adrian Schröter <adrian@suse.de>
- update to version 0.2.2
  * FFmpeg 3 & 4 support
  * Fixed crash with masks and transitions
  * Fixed many bugs around FPS and video length calculation (especially for MP3 and streaming WEBM formats)
  * Protecting samples_per_frame calculation to keep from crashing on undetected FPS
  * OpenMP schedule change (added stability)
  * Limiting threads for both FFmpeg and OpenMP (attempting to find a good balance of parallel performance, while not spawning too many threads). Sometimes more is not always better.
  * Travis CI integration
  * Fix install paths for headers and effects (Jeff Shillitto - jeffski)
  * Fix bug with FFmpeg > 3.2 flushing frames (Jeff Shillitto - jeffski)
  * Adding "reader" property for Mask effect, to allow the user to adjust the image or video used by the mask effect.
  * Fixing bitrate calculation (to be in bytes instead of bits)
  * Adding in FPS detection for files which don't have valid FPS. In those cases (streaming files for example), we iterate through all packets, and average the # of frames, duration, bit rate, etc... Not ideal, but a better fallback.
- soname change to 16
* Mon Jul  2 2018 adrian@suse.de
- update to version 0.2.0
  * FFMPEG 3.2.0 support
  * New video effects
  * bugfixes
  * new soname
- return to ffmpeg3-devel BuildRequires
  * ffmpeg4 is not supported
  * exact version numbers are bad in case of new ffmpeg3 release
* Fri May  4 2018 olaf@aepfle.de
- Use ffmpeg3 versions of pkgconfig(libav*)
* Sat Apr 21 2018 jengelh@inai.de
- Explicitly request ffmpeg 3.x for building
* Tue Mar  6 2018 adrian@suse.de
- update to version 0.1.9
  going back to git, as the tar is poorly named and not signed
* Wed Nov  1 2017 tampakrap@opensuse.org
- Replace the _service file with the upstream tarball
* Mon Sep 11 2017 adrian@suse.de
- update to version 0.1.8
* Sat Sep  2 2017 zaitor@opensuse.org
- Update to version 0.1.7
- Bump so version following upstream changes.
* Mon Apr  3 2017 adrian@suse.de
- update to version 0.1.4
* Fri Jan 13 2017 jengelh@inai.de
- Update description
* Thu Jan 12 2017 adrian@suse.de
- adapt for build.o.o from packman version
* Thu Jan  5 2017 avvissu@yandex.by
- Update to 0.1.3:
  * This release does not have a changelog
* Thu Oct 20 2016 avvissu@yandex.by
- Initial package
